/*
** Module   : RectangleWidget.java
** Abstract :
**
** Copyright (c) 2010-2013, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- ---------------------------------Description----------------------------------
** 001 SIY 20101002 Created initial version
** 002 SIY 20111101 Updated imports.
** 003 CA  20130222 Added NPE protection for cases when a widget is used before is 
**                  attached to a frame (after a CREATE WIDGET statement is used).
** 004 CA  20130927 Added LegacyResource annotation, to determine resource type.
** 005 CA  20131115 Changes related to properly instantiate dynamic resources.
*/

package com.goldencode.p2j.ui;

import com.goldencode.p2j.util.*;

/**
 * Rectangle widget.
 * 
 * @author 	SIY
 * @version 1.0
 */
@LegacyResource(resource = LegacyResource.RECTANGLE)
public class RectangleWidget
extends ControlEntity
{
   /** Rectangle-specific configuration. */
   private RectangleConfig rc;

   /**
    * Default constructor.
    */
   public RectangleWidget()
   {
      this(false);
   }

   /**
    * Default constructor.
    * 
    * @param    dynamic
    *           Flag indicating if this is a static or dynamic resource.
    */
   public RectangleWidget(boolean dynamic)
   {
      super(dynamic, new RectangleConfig(ComponentConfig.RECTANGLE));
      this.rc = (RectangleConfig) config;
   }

   /**
    * Set NO-FILL option.
    * 
    * @param   flag
    *          New value for the option.
    */
   public void setNoFill(boolean flag)
   {
      rc.setNoFill(flag);
      pushScreenDefinition();
   }

   /**
    * Set EDGE-PIXELS option.
    * 
    * @param   pixels
    *          Option value.
    */
   public void setEdgePixels(double pixels)
   {
      rc.setEdgePixels(pixels);
      pushScreenDefinition();
   }

   /**
    * Set GRAPHIC-EDGE option.
    * 
    * @param   flag
    *          New value for the option.
    */
   public void setGraphicEdge(boolean flag)
   {
      rc.setGraphicEdge(flag);
      pushScreenDefinition();
   }

   /**
    * Set rectangle width.
    * 
    * @param   width
    *          New rectangle width.
    */
   public void setWidth(double width)
   {
      rc.setWidth(width);
      pushScreenDefinition();
   }

   /**
    * Set rectangle height.
    * 
    * @param   height
    *          New rectangle width.
    */
   public void setHeight(double height)
   {
      rc.setHeight(height);
      pushScreenDefinition();
   }
}
