/*
** Module   : Scopeable.java
** Abstract : the interface for objects whose changes must be externally 
**            initialized at scope start and finalized at scope exit
**
** Copyright (c) 2005-2013, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- --JPRM-- -----------------------------Description-----------------------------
** 001 GES 20050817   @22162 Created initial version, providing an interface for objects needing 
**                           initialization and termination callbacks at the start and end of 
**                           every block entered and exited.
** 005 CA  20131013          Added scopeDeleted() API, which will be called when the instantiating 
**                           procedure where this scopeable instance was registered gets deleted.
*/

package com.goldencode.p2j.util;

/**
 * An interface for objects needing initialization and termination callbacks
 * at the start and end of every block entered and exited.  The exit is 
 * guaranteed to be called no matter how the flow of control exits the block
 * (exception, break, return or via the flow of control passing through the
 * natural end of the block). 
 */
public interface Scopeable
{
   /**
    * Provides a notification that a new scope is about to be entered.
    */
   public void scopeStart();
   
   /**
    * Provides a notification that a scope is about to be exited.
    */
   public void scopeFinished();
   
   /**
    * Provides a notification that an external scope is about to be deleted.
    */
   public void scopeDeleted();
}
